==> phpgroupware-jp-0.9.16.003-pre1.tar.bz2: phpgroupware/calendar/index.php <==
<?php
  /**************************************************************************\
  * phpGroupWare - Calendar                                                  *
  * http://www.phpgroupware.org                                              *
  * Based on Webcalendar by Craig Knudsen <cknudsen@radix.net>               *
  *          http://www.radix.net/~cknudsen                                  *
  * Modified by Mark Peters <skeeter@phpgroupware.org>                       *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

	/* $Id: index.php,v 1.1.1.1 2003/06/12 18:02:03 kazuyan Exp $ */

	$phpgw_flags = Array(
		'currentapp'	=>	'calendar',
		'noheader'	=>	True,
		'nonavbar'	=>	True,
		'noappheader'	=>	True,
		'noappfooter'	=>	True,
		'nofooter'	=>	True
	);

	$GLOBALS['phpgw_info']['flags'] = $phpgw_flags;
	
	include('../header.inc.php');
	if(!is_object($GLOBALS['phpgw']->datetime))
	{
		$GLOBALS['phpgw']->datetime = CreateObject('phpgwapi.datetime');
	}
	
	$parms = Array(
		'menuaction'=> 'calendar.uicalendar.index',
		'date'		=> date('Ymd',$GLOBALS['phpgw']->datetime->users_localtime)
	);
	
//	echo 'Local DateTime: '.date('Ymd H:i:s',$GLOBALS['phpgw']->datetime->users_localtime).'<br>'."\n";

	Header('Location: '.$GLOBALS['phpgw']->link('/index.php',$parms));
	$GLOBALS['phpgw']->common->phpgw_exit();
?>

==> phpgroupware-jp-0.9.16.012-pre1.tar.bz2: phpgroupware/calendar/index.php <==
<?php
  /**************************************************************************\
  * phpGroupWare - Calendar                                                  *
  * http://www.phpgroupware.org                                              *
  * Based on Webcalendar by Craig Knudsen <cknudsen@radix.net>               *
  *          http://www.radix.net/~cknudsen                                  *
  * Modified by Mark Peters <skeeter@phpgroupware.org>                       *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

	/* $Id: index.php,v 1.1.1.2.18.1 2007/09/16 22:23:35 kazuyan Exp $ */

	$phpgw_flags = Array(
		'currentapp'	=>	'calendar',
		'noheader'	=>	True,
		'nonavbar'	=>	True,
		'noappheader'	=>	True,
		'noappfooter'	=>	True,
		'nofooter'	=>	True
	);

	$GLOBALS['phpgw_info']['flags'] = $phpgw_flags;
	
	include('../header.inc.php');
	if(!is_object($GLOBALS['phpgw']->datetime))
	{
		$GLOBALS['phpgw']->datetime = CreateObject('phpgwapi.phpgw_datetime');
	}
	
	$parms = Array(
		'menuaction'=> 'calendar.uicalendar.index',
		'date'		=> date('Ymd',$GLOBALS['phpgw']->datetime->users_localtime)
	);
	
//	echo 'Local DateTime: '.date('Ymd H:i:s',$GLOBALS['phpgw']->datetime->users_localtime).'<br />'."\n";

	Header('Location: '.$GLOBALS['phpgw']->link('/index.php',$parms));
	$GLOBALS['phpgw']->common->phpgw_exit();
?>
